# AdviserResultResponseResultReportPipeline

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**boots** | [**list[UnitDef]**](UnitDef.md) | Boot pipeline unit types registered to the resolution process  |
**pseudonyms** | [**list[UnitDef]**](UnitDef.md) | Pseudonym pipeline unit types registered to the resolution process  |
**sieves** | [**list[UnitDef]**](UnitDef.md) | Sieve pipeline unit types registered to the resolution process  |
**steps** | [**list[UnitDef]**](UnitDef.md) | Step pipeline unit types registered to the resolution process  |
**strides** | [**list[UnitDef]**](UnitDef.md) | Stride pipeline unit types registered to the resolution process  |
**wraps** | [**list[UnitDef]**](UnitDef.md) | Wrap pipeline unit types registered to the resolution process  |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

